# Overview
Thin wrapper around [Mastodon.py](https://github.com/halcy/Mastodon.py).

# Dependencies
* Unix-like OS.
* [Python](https://www.python.org/) 3.8 or newer
* [Mastodon.py](https://github.com/halcy/Mastodon.py)
